@@ -387,8 +387,9 @@ static struct dispatch_actions actions[] = {
 	{PRIV_GET_HOSTNAME, asroot_gethostname},
 #ifdef HOST_OS_LINUX
 	{PRIV_OPEN, asroot_open},
+# ifdef ENABLE_OLDIES
 	{PRIV_ETHTOOL, asroot_ethtool},
-	{PRIV_IFACE_MAC, asroot_iface_mac},
+# endif
 #endif
 	{PRIV_IFACE_INIT, asroot_iface_init},
 	{PRIV_IFACE_MULTICAST, asroot_iface_multicast},
