@@ -47,7 +47,7 @@
 #define LLDP_PORTID_SUBTYPE_LOCAL	7
 #define LLDP_PORTID_SUBTYPE_MAX		LLDP_PORTID_SUBTYPE_LOCAL
 
-/* Operational MAU Type field, from RFC 3636 */
+/* Operational MAU Type field, from RFC 3636 (see IANAifMauTypeListBits) */
 #define LLDP_DOT3_MAU_AUI		1
 #define LLDP_DOT3_MAU_10BASE5		2
 #define LLDP_DOT3_MAU_FOIRL		3
@@ -88,6 +88,19 @@
 #define LLDP_DOT3_MAU_10GIGBASEEW	38
 #define LLDP_DOT3_MAU_10GIGBASELW	39
 #define LLDP_DOT3_MAU_10GIGBASESW	40
+#define LLDP_DOT3_MAU_10GIGBASECX4	41
+#define LLDP_DOT3_MAU_2BASETL		42
+#define LLDP_DOT3_MAU_10PASSTS		43
+#define LLDP_DOT3_MAU_100BASEBX10D	44
+#define LLDP_DOT3_MAU_100BASEBX10U	45
+#define LLDP_DOT3_MAU_100BASELX10	46
+#define LLDP_DOT3_MAU_1000BASEBX10D	47
+#define LLDP_DOT3_MAU_1000BASEBX10U	48
+#define LLDP_DOT3_MAU_1000BASELX10	49
+#define LLDP_DOT3_MAU_1000BASEPX10D	50
+#define LLDP_DOT3_MAU_1000BASEPX10U	51
+#define LLDP_DOT3_MAU_1000BASEPX20D	52
+#define LLDP_DOT3_MAU_1000BASEPX20U	53
 
 /* Dot3 Power Devicetype */
 #define LLDP_DOT3_POWER_PSE	1
@@ -116,7 +129,7 @@
 #define LLDP_DOT3_POWER_PRIO_HIGH	2
 #define LLDP_DOT3_POWER_PRIO_LOW	3
 
-/* PMD Auto-Negotiation Advertised Capability field, from RFC 3636 */
+/* PMD Auto-Negotiation Advertised Capability field, from RFC 3636 (see IANAifMauAutoNegCapBits) */
 #define LLDP_DOT3_LINK_AUTONEG_OTHER		0x8000
 #define LLDP_DOT3_LINK_AUTONEG_10BASE_T		0x4000
 #define LLDP_DOT3_LINK_AUTONEG_10BASET_FD	0x2000
@@ -230,4 +243,11 @@
 #define LLDP_BOND_SLAVE_SRC_MAC_TYPE_LOCALLY_ADMINISTERED 4
 #define LLDP_BOND_SLAVE_SRC_MAC_TYPE_MAX LLDP_BOND_SLAVE_SRC_MAC_TYPE_LOCALLY_ADMINISTERED
 
+/* Agent types */
+#define LLDP_AGENT_TYPE_UNKNOWN			0
+#define LLDP_AGENT_TYPE_NEAREST_BRIDGE		1
+#define LLDP_AGENT_TYPE_NEAREST_NONTPMR_BRIDGE	2
+#define LLDP_AGENT_TYPE_NEAREST_CUSTOMER_BRIDGE	3
+#define LLDP_AGENT_TYPE_MAX			LLDP_AGENT_TYPE_NEAREST_CUSTOMER_BRIDGE
+
 #endif /* _LLDP_H */
